@@ -11,6 +11,7 @@ __author__ = 'Martin Pitt'
 __copyright__ = '(c) 2012 Canonical Ltd.'
 
 import copy
+import functools
 import importlib
 import importlib.util
 import os
@@ -120,6 +121,43 @@ def _wrap_in_dbus_variant(value):
     raise dbus.exceptions.DBusException(f'could not wrap type {type(value)}')
 
 
+def _convert_args(signature: str, args: Tuple[Any, ...]) -> List[Any]:
+    """
+    Convert types of arguments according to signature, using
+    MethodCallMessage.append(); this will also provide type/length
+    checks, except for the case of an empty signature
+    """
+    try:
+        if signature == '' and len(args) > 0:
+            raise TypeError('Fewer items found in D-Bus signature than in Python arguments')
+        m = dbus.connection.MethodCallMessage('a.b', '/a', 'a.b', 'a')
+        m.append(signature=signature, *args)
+        return m.get_args_list()
+    except Exception as e:
+        raise dbus.exceptions.DBusException(f'Invalid arguments: {str(e)}',
+                                            name='org.freedesktop.DBus.Error.InvalidArgs')
+
+
+def loggedmethod(self, func):
+    """Decorator for a method to end in the call log"""
+
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        fname = func.__name__
+        self_arg, args = args[0], args[1:]
+
+        in_signature = getattr(func, '_dbus_in_signature', '')
+        args = _convert_args(in_signature, args)
+
+        self.log(fname + _format_args(args))
+        self.call_log.append((int(time.time()), fname, args))
+        self.MethodCalled(fname, args)
+
+        return func(*[self_arg, *args], **kwargs)
+
+    return wrapper
+
+
 class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-attributes
     '''Mock D-Bus object
 
@@ -174,8 +212,11 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         self._reset(props)
 
     def __del__(self) -> None:
-        if self.logfile and self.is_logfile_owner:
-            self.logfile.close()
+        try:
+            if self.logfile and self.is_logfile_owner:
+                self.logfile.close()
+        except AttributeError:
+            pass
 
     def _set_up_object_manager(self) -> None:
         '''Set up this mock object as a D-Bus ObjectManager.'''
@@ -548,6 +589,8 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
             # pylint: disable=protected-access
             fn = getattr(module, symbol)
             if ('_dbus_interface' in dir(fn) and ('_dbus_is_signal' not in dir(fn) or not fn._dbus_is_signal)):
+                fn = loggedmethod(self, fn)
+
                 # for dbus-python compatibility, add methods as callables
                 setattr(self.__class__, symbol, fn)
                 self.methods.setdefault(fn._dbus_interface, {})[str(symbol)] = (
@@ -567,7 +610,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sssav',
                          out_signature='')
-    def EmitSignal(self, interface: str, name: str, signature: str, args: List[Any]) -> None:
+    def EmitSignal(self, interface: str, name: str, signature: str, sigargs: Tuple[Any, ...]) -> None:
         '''Emit a signal from the object.
 
         interface: D-Bus interface to send the signal from. For convenience you
@@ -584,14 +627,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         if not interface:
             interface = self.interface
 
-        # convert types of arguments according to signature, using
-        # MethodCallMessage.append(); this will also provide type/length
-        # checks, except for the case of an empty signature
-        if signature == '' and len(args) > 0:
-            raise TypeError('Fewer items found in D-Bus signature than in Python arguments')
-        m = dbus.connection.MethodCallMessage('a.b', '/a', 'a.b', 'a')
-        m.append(signature=signature, *args)
-        args = m.get_args_list()
+        args = _convert_args(signature, sigargs)
 
         fn = lambda self, *args: self.log(f'emit {self.path} {interface}.{name}{_format_args(args)}')
         fn.__name__ = str(name)
@@ -654,38 +690,35 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
                                            'oas', [dbus.ObjectPath(path),
                                                    objects[path].props])
 
-    def mock_method(self, interface: str, dbus_method: str, in_signature: str, *args, **_) -> Any:
+    def mock_method(self, interface: str, dbus_method: str, in_signature: str, *m_args, **_) -> Any:
         '''Master mock method.
 
         This gets "instantiated" in AddMethod(). Execute the code snippet of
         the method and return the "ret" variable if it was set.
         '''
-        # print('mock_method', dbus_method, self, in_signature, args, kwargs, file=sys.stderr)
+        # print('mock_method', dbus_method, self, in_signature, args, _, file=sys.stderr)
 
-        # convert types of arguments according to signature, using
-        # MethodCallMessage.append(); this will also provide type/length
-        # checks, except for the case of an empty signature
-        if in_signature == '' and len(args) > 0:
-            raise TypeError('Fewer items found in D-Bus signature than in Python arguments')
-        m = dbus.connection.MethodCallMessage('a.b', '/a', 'a.b', 'a')
-        m.append(signature=in_signature, *args)
-        args = m.get_args_list()
+        try:
+            args = _convert_args(in_signature, m_args)
 
-        self.log(dbus_method + _format_args(args))
-        self.call_log.append((int(time.time()), str(dbus_method), args))
-        self.MethodCalled(dbus_method, args)
+            self.log(dbus_method + _format_args(args))
+            self.call_log.append((int(time.time()), str(dbus_method), args))
+            self.MethodCalled(dbus_method, args)
 
-        # The code may be a Python 3 string to interpret, or may be a function
-        # object (if AddMethod was called from within Python itself, rather than
-        # over D-Bus).
-        code = self.methods[interface][dbus_method][2]
-        if code and isinstance(code, types.FunctionType):
-            return code(self, *args)
-        if code:
-            loc = locals().copy()
-            exec(code, globals(), loc)  # pylint: disable=exec-used
-            if 'ret' in loc:
-                return loc['ret']
+            # The code may be a Python 3 string to interpret, or may be a function
+            # object (if AddMethod was called from within Python itself, rather than
+            # over D-Bus).
+            code = self.methods[interface][dbus_method][2]
+            if code and isinstance(code, types.FunctionType):
+                return code(self, *args)
+            if code:
+                loc = locals().copy()
+                exec(code, globals(), loc)  # pylint: disable=exec-used
+                if 'ret' in loc:
+                    return loc['ret']
+        except Exception as e:
+            self.log(dbus_method + ' raised: ' + str(e))
+            raise e
 
         return None
 
