@@ -9,6 +9,8 @@
 __author__ = 'Martin Pitt'
 __copyright__ = '(c) 2012 Canonical Ltd.'
 
+import importlib.util
+import os
 import unittest
 import shutil
 import sys
@@ -66,7 +68,16 @@ class TestCLI(dbusmock.DBusTestCase):
     def test_template_upower(self):
         self.start_mock(['-t', 'upower'],
                         'org.freedesktop.UPower', '/org/freedesktop/UPower', True)
+        self.check_upower_running()
 
+    def test_template_upower_explicit_path(self):
+        spec = importlib.util.find_spec('dbusmock.templates.upower')
+        self.assertTrue(os.path.exists(spec.origin))
+        self.start_mock(['-t', spec.origin],
+                        'org.freedesktop.UPower', '/org/freedesktop/UPower', True)
+        self.check_upower_running()
+
+    def check_upower_running(self):
         # check that it actually ran the template, if we have upower
         if have_upower:
             out = subprocess.check_output(['upower', '--dump'],
@@ -81,6 +92,7 @@ class TestCLI(dbusmock.DBusTestCase):
         # --system is redundant here, but should not break
         self.start_mock(['--system', '-t', 'upower'],
                         'org.freedesktop.UPower', '/org/freedesktop/UPower', True)
+        self.check_upower_running()
 
     def test_template_override_session(self):
         self.start_mock(['--session', '-t', 'upower'],
